yakumo.base.GlanceV2SubManager

Package yakumo :: Module base :: Class GlanceV2SubManager |
[hide private]
[frames] | no frames]

# Class GlanceV2SubManager

source code

     object --+
              |
        Manager --+
                  |
         SubManager --+
                      |
     object --+       |
              |       |
        Manager --+   |
                  |   |
    GlanceV2Manager --+
                      |
                     GlanceV2SubManager

Known Subclasses:
  - glance.v2.image_member.Manager

Base class for sub resource managers for GlanceV2Manager.

Instance Methods | [hide private]
Inherited from `SubManager`: `__init__` Inherited from `GlanceV2Manager`: `create`, `get` Inherited from `Manager`: `find`, `find_one`, `get_empty`, `list` Inherited from `Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `GlanceV2Manager` (private): `_has_extra_attr` Inherited from `Manager`: `resource_class`, `service_type` Inherited from `Manager` (private): `_attr_mapping`, `_has_detail`, `_hidden_methods`, `_id_attr`, `_json_resource_key`, `_json_resources_key`, `_update_method`, `_url_resource_list_path`, `_url_resource_path`

Properties | [hide private]
Inherited from `object`: `__class__`